@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.13'
+__version__ = '0.1.14'
 
 try:
     from importlib import import_module
@@ -31,8 +31,14 @@ from logging import getLogger
 from unittest import TestCase
 from types import ModuleType
 
+
+class FluentAnyArguments(object):
+    pass
+
+
 LOGGER = getLogger(__name__)
 
+ANY_ARGUMENTS = FluentAnyArguments()
 AT_LEAST_ONCE = 'AT-LEAST-ONCE'
 NEVER = 'NEVER'
 
@@ -41,13 +47,6 @@ _patch_entries = []
 _call_entries = []
 
 
-class FluentAnyArguments(object):
-    pass
-
-
-ANY_ARGUMENTS = FluentAnyArguments()
-
-
 class UnitTests(TestCase):
 
     def setUp(self):
@@ -116,25 +115,22 @@ class FluentAnswer(object):
 
         return answer()
 
-    def append_answer(self, answer_class, value):
-        answer = answer_class(value)
-        self._answers.append(answer)
-
     def then_return(self, value):
-        self.append_answer(self.AnswerByReturning, value)
+        answer = self.AnswerByReturning(value)
+        self._answers.append(answer)
         return self
 
     def then_raise(self, value):
-        self.append_answer(self.AnswerByRaising, value)
+        answer = self.AnswerByRaising(value)
+        self._answers.append(answer)
         return self
 
 
 class FluentPatchEntry(FluentTarget):
 
-    def __init__(self, target, attribute_name, original):
+    def __init__(self, target, attribute_name):
         FluentTarget.__init__(self, target)
         self._attribute_name = attribute_name
-        self._original = original
         self._patch = None
         self._mock = None
         self._full_qualified_target_name = None
@@ -219,16 +215,13 @@ class FluentWhen(FluentTarget):
     def __init__(self, target):
         FluentTarget.__init__(self, target)
 
-    def _get_original_attribute(self, name):
-
+    def _check_target_has_attribute(self, name):
         if not hasattr(self._target, name):
             raise InvalidAttributeError(self._target_name, name)
 
-        return getattr(self._target, name)
-
     def __getattr__(self, name):
-        original = self._get_original_attribute(name)
-        patch_entry = FluentPatchEntry(self._target, name, original)
+        self._check_target_has_attribute(name)
+        patch_entry = FluentPatchEntry(self._target, name)
         _patch_entries.append(patch_entry)
 
         configurator_key = (self._target, name)
@@ -307,8 +300,8 @@ class Verifier(FluentTarget):
         self._times = times
 
         if times not in [NEVER, AT_LEAST_ONCE]:
-            error_message = 'Times can be {never} or {once}.'.format(never=NEVER, once=AT_LEAST_ONCE)
-            raise NotImplementedError(error_message)
+            error_message = 'Argument times can be "{never}" or "{once}".'.format(never=NEVER, once=AT_LEAST_ONCE)
+            raise ValueError(error_message)
 
     def __getattr__(self, name):
         self._attribute_name = name
@@ -387,3 +380,16 @@ def get_patches():
 
 def verify(target, times=AT_LEAST_ONCE):
     return Verifier(target, times)
+
+
+def create_mock(*arguments, **keyword_arguments):
+    if len(arguments) > 0:
+        specification = arguments[0]
+        mock = Mock(specification)
+    else:
+        mock = Mock()
+
+    for property_name in keyword_arguments.keys():
+        setattr(mock, property_name, keyword_arguments[property_name])
+
+    return mock
